aboutsummaryrefslogtreecommitdiffstats
path: root/serd/serd.h
diff options
context:
space:
mode:
authorDavid Robillard <d@drobilla.net>2011-01-23 08:16:49 +0000
committerDavid Robillard <d@drobilla.net>2011-01-23 08:16:49 +0000
commitc7dfad1db675f417b09fd3748473b26cc0ea85be (patch)
treec9c52766184c0fa6d28c0dafe64b2a8de5cdee25 /serd/serd.h
parenta3c9e1dacb76cf0282d8419fa13a41d322046e60 (diff)
downloadserd-c7dfad1db675f417b09fd3748473b26cc0ea85be.tar.gz
serd-c7dfad1db675f417b09fd3748473b26cc0ea85be.tar.bz2
serd-c7dfad1db675f417b09fd3748473b26cc0ea85be.zip
SerdNodeType => SerdType.
git-svn-id: http://svn.drobilla.net/serd/trunk@43 490d8e77-9747-427b-9fa3-0b8f29cee8a0
Diffstat (limited to 'serd/serd.h')
-rw-r--r--serd/serd.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/serd/serd.h b/serd/serd.h
index 8f8dfdf3..5258b4fb 100644
--- a/serd/serd.h
+++ b/serd/serd.h
@@ -68,7 +68,7 @@ typedef enum {
* node is either a resource, literal, or blank. In syntax there are two
* ways to refer to a resource (URI or CURIE), and two ways to refer to a
* blank node (with a blank ID, or anonymously). Serd represents nodes as
* an unquoted UTF-8 string "value" associated with a @ref SerdNodeType,
* which preserves syntactic information allowing for lossless abbreviation.
* A non-abbreviating sink may simply consider @ref SERD_ANON_BEGIN and
* @ref SERD_ANON equivalent to SERD_BLANK_ID.
@@ -107,7 +107,7 @@ typedef enum {
*/
SERD_ANON = 6
-} SerdNodeType;
+} SerdType;
/** @name SerdURI
* A parsed URI.
@@ -248,11 +248,11 @@ typedef bool (*SerdPrefixSink)(void* handle,
typedef bool (*SerdStatementSink)(void* handle,
const SerdString* graph,
const SerdString* subject,
- SerdNodeType subject_type,
+ SerdType subject_type,
const SerdString* predicate,
- SerdNodeType predicate_type,
+ SerdType predicate_type,
const SerdString* object,
- SerdNodeType object_type,
+ SerdType object_type,
const SerdString* object_lang,
const SerdString* object_datatype);
@@ -331,11 +331,11 @@ bool
serd_writer_write_statement(SerdWriter writer,
const SerdString* graph,
const SerdString* subject,
- SerdNodeType subject_type,
+ SerdType subject_type,
const SerdString* predicate,
- SerdNodeType predicate_type,
+ SerdType predicate_type,
const SerdString* object,
- SerdNodeType object_type,
+ SerdType object_type,
const SerdString* object_datatype,
const SerdString* object_lang);
@@ -68,7 +68,7 @@ typedef enum {
* ways to refer to a resource (URI or CURIE), and two ways to refer to a
* blank node (with a blank ID, or anonymously). Serd represents nodes as
- * an unquoted UTF-8 string "value" associated with a @ref SerdNodeType,
+ * an unquoted UTF-8 string "value" associated with a @ref SerdType,
* which preserves syntactic information allowing for lossless abbreviation.
* A non-abbreviating sink may simply consider @ref SERD_ANON_BEGIN and